pub enum BlockchainWriteRequest {
WriteBlock(VerifiedBlockInformation),
BatchWriteBlocks(Vec<VerifiedBlockInformation>),
WriteAltBlock(AltBlockInformation),
PopBlocks(usize),
FlushAltBlocks,
}Expand description
A write request to the blockchain database.
Variants
WriteBlock(VerifiedBlockInformation)
Request that a block be written to the database.
Input is an already verified block.
BatchWriteBlocks(Vec<VerifiedBlockInformation>)
Request that a batch of blocks be written to the database.
Input is an already verified batch of blocks.
WriteAltBlock(AltBlockInformation)
Write an alternative block to the database,
Input is the alternative block.
PopBlocks(usize)
A request to pop some blocks from the top of the main chain
Input is the amount of blocks to pop.
This request flushes all alt-chains from the cache before adding the popped blocks to the alt cache.
FlushAltBlocks
A request to flush all alternative blocks.